wikiglot.Wiktionary
===================

.. currentmodule:: wikiglot

.. autoclass:: Wiktionary
   :members:
   :show-inheritance:
   :inherited-members:
   :special-members: __call__, __add__, __mul__, __init__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~Wiktionary.lemmatize
      ~Wiktionary.lookup
   
   

   
   
   